==> haskell-text-latin1-0.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3
id: text-latin1-0.3-227Ci4RixWXG6lWZgYn13J
key: text-latin1-0.3-227Ci4RixWXG6lWZgYn13J
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
abi: 56ed6362e599f0b9e7c7459912474f99
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-latin1-0.3
hs-libraries: HStext-latin1-0.3-227Ci4RixWXG6lWZgYn13J
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    data-checked-0.3-HVfY8aafhekBqF3684CsqD
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3
id: text-latin1-0.3-Acd4YfiOX484VCt0O5ys5d
key: text-latin1-0.3-Acd4YfiOX484VCt0O5ys5d
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
abi: c6074e7889b71209599dec2fe8752944
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-latin1-0.3
hs-libraries: HStext-latin1-0.3-Acd4YfiOX484VCt0O5ys5d
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
    data-checked-0.3-HVfY8aafhekBqF3684CsqD
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
